package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWpwzlyqk;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWpy;
import com.ruoyi.tcZz.service.ITcWpyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网评员Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "网评员")
@RequestMapping("/tcZz/networkEcology/wpy")
public class TcWpyController extends BaseController {
    @Autowired
    private ITcWpyService tcWpyService;

    /**
     * 查询网评员列表
     */
    @ApiOperation(value = "查询网评员列表", response = TcWpy.class)
    @GetMapping("/list")
    public TableDataInfo list(TcWpy tcWpy) {
        startPage();
        List<TcWpy> list = tcWpyService.selectTcWpyList(tcWpy);
        return getDataTable(list);
    }

    /**
     * 导出网评员列表
     */
    @ApiOperation(value = "导出网评员列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWpy tcWpy) {
        List<TcWpy> list = tcWpyService.selectTcWpyList(tcWpy);
        ExcelUtil<TcWpy> util = new ExcelUtil<TcWpy>(TcWpy.class);
        util.exportExcel(response, list, "网评员数据");
    }

    /**
     * 获取网评员详细信息
     */
    @ApiOperation(value = "获取网评员详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWpyService.selectTcWpyById(id));
    }

    /**
     * 新增网评员
     */
    @ApiOperation(value = "新增网评员")
    @PostMapping
    public AjaxResult add(@RequestBody TcWpy tcWpy) {
        return toAjax(tcWpyService.insertTcWpy(tcWpy));
    }

    /**
     * 修改网评员
     */
    @ApiOperation(value = "修改网评员")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWpy tcWpy) {
        return toAjax(tcWpyService.updateTcWpy(tcWpy));
    }

    /**
     * 删除网评员
     */
    @ApiOperation(value = "删除网评员")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWpyService.deleteTcWpyByIds(ids));
    }



    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWpy> util = new ExcelUtil<TcWpy>(TcWpy.class);
        List<TcWpy> tcWpyList = util.importExcel(file.getInputStream());
        tcWpyService.importUser(tcWpyList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWpyService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWpy> util = new ExcelUtil<TcWpy>(TcWpy.class);
        util.importTemplateExcel(response, " 网评员");
    }
}
